==> classpath-0.11-rc1.tar.gz: classpath-0.11-rc1/javax/print/attribute/standard/NumberUpSupported.java <==
/* NumberUpSupported.java --
   Copyright (C) 2004 Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
02111-1307 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */

package javax.print.attribute.standard;

import javax.print.attribute.SetOfIntegerSyntax;
import javax.print.attribute.SupportedValuesAttribute;


/**
 * @author Michael Koch (konqueror@gmx.de)
 */
public final class NumberUpSupported extends SetOfIntegerSyntax
  implements SupportedValuesAttribute
{
  private static final long serialVersionUID = -1041573395759141805L;

  /**
   * Constructs a <code>NumberUp</code> object.
   */
  public NumberUpSupported(int member)
  {
    super(member);
  }

  /**
   * Constructs a <code>NumberUp</code> object.
   */
  public NumberUpSupported(int[][] members)
  {
    super(members);
  }

  /**
   * Constructs a <code>NumberUp</code> object.
   */
  public NumberUpSupported(int lowerBound, int upperBound)
  {
    super(lowerBound, upperBound);
  }

  /**
   * Returns category of this class.
   *
   * @return the class <code>NumberUpSupported</code> itself
   */
  public final Class getCategory()
  {
    return NumberUpSupported.class;
  }

  /**
   * Returns the name of this attribute.
   *
   * @return the name
   */
  public final String getName()
  {
    return "number-up-supported";
  }
}

==> classpath-0.12.tar.gz: classpath-0.12/javax/print/attribute/standard/NumberUpSupported.java <==
/* NumberUpSupported.java --
   Copyright (C) 2004 Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
02111-1307 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */

package javax.print.attribute.standard;

import javax.print.attribute.SetOfIntegerSyntax;
import javax.print.attribute.SupportedValuesAttribute;


/**
 * @author Michael Koch (konqueror@gmx.de)
 */
public final class NumberUpSupported extends SetOfIntegerSyntax
  implements SupportedValuesAttribute
{
  private static final long serialVersionUID = -1041573395759141805L;

  /**
   * Constructs a <code>NumberUp</code> object.
   */
  public NumberUpSupported(int member)
  {
    super(member);
  }

  /**
   * Constructs a <code>NumberUp</code> object.
   */
  public NumberUpSupported(int[][] members)
  {
    super(members);
  }

  /**
   * Constructs a <code>NumberUp</code> object.
   */
  public NumberUpSupported(int lowerBound, int upperBound)
  {
    super(lowerBound, upperBound);
  }

  /**
   * Returns category of this class.
   *
   * @return the class <code>NumberUpSupported</code> itself
   */
  public Class getCategory()
  {
    return NumberUpSupported.class;
  }

  /**
   * Returns the name of this attribute.
   *
   * @return the name
   */
  public String getName()
  {
    return "number-up-supported";
  }
}
